==> tecfy_core_package-1.0.23.tar.gz: lib/views/components/entity/dropdown.property.dart <==
// import 'package:flutter/material.dart';
// import 'package:tecfy_core_package/services/app_localizations.dart';
// import 'package:tecfy_core_package/services/entity.service.dart';
part of tecfy_core_client_package;

class DropdownEntity extends StatefulWidget {
  final Entity entity;
  final String? label;
  final String? initalValue;
  final String? filterField;
  final String? filterValue;
  final bool isFilter;
  final void Function(String?)? onChanged;
  DropdownEntity(
      {this.label,
      required this.entity,
      this.initalValue,
      this.onChanged,
      this.isFilter = false,
      this.filterField,
      this.filterValue});
  @override
  _DropdownEntityState createState() => _DropdownEntityState();
}

class _DropdownEntityState extends State<DropdownEntity> {
  List<dynamic>? _data;
  String? _value;
  @override
  void initState() {
    _value = widget.initalValue;
    EntityService.getData(widget.entity).then((result) {
      if (result.success) {
        _data = result.data;
        if ((_data?.length ?? 0) == 1) {
          _value = _data?[0]['id'];
          widget.onChanged?.call(_value);
        }
        setState(() {});
      } else
        result.showMessage(context);
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _data == null
        ? Text('${AppLocale.translate(context, 'Loading')}..')
        : DropdownButtonFormField<String>(
            decoration: InputDecoration(labelText: widget.label),
            value: _data?.any((d) =>
                        (!widget.isFilter ||
                            widget.filterValue == d[widget.filterField]) &&
                        d['id'] == _value) ??
                    false
                ? _value
                : null,
            onChanged: (v) {
              _value = v;
              if (widget.onChanged != null) widget.onChanged?.call(v);
              setState(() {});
            },
            items: (_data
                    ?.where((d) =>
                        !widget.isFilter ||
                        widget.filterValue == d[widget.filterField])
                    .map<DropdownMenuItem<String>>((item) => DropdownMenuItem(
                          child: Text(item['display'] ??
                              item['name'] ??
                              item['nameAr'] ??
                              item['nameEn'] ??
                              'N/A'),
                          value: item['id'],
                        ))
                    .toList() ??
                [])
              ..add(_value == null
                  ? DropdownMenuItem(
                      child: Container(),
                    )
                  : DropdownMenuItem(
                      child:
                          Text('غير محدد', style: TextStyle(color: Colors.red)),
                      value: null,
                    )),
          );
  }
}

==> tecfy_core_package-1.0.58.tar.gz: lib/views/components/entity/dropdown.property.dart <==
// import 'package:flutter/material.dart';
// import 'package:tecfy_core_package/services/app_localizations.dart';
// import 'package:tecfy_core_package/services/entity.service.dart';
part of tecfy_core_client_package;

class DropdownEntity extends StatefulWidget {
  final Entity entity;
  final String? label;
  final String? initalValue;
  final String? filterField;
  final String? filterValue;
  final bool isFilter;
  final void Function(String?)? onChanged;
  DropdownEntity(
      {this.label,
      required this.entity,
      this.initalValue,
      this.onChanged,
      this.isFilter = false,
      this.filterField,
      this.filterValue});
  @override
  _DropdownEntityState createState() => _DropdownEntityState();
}

class _DropdownEntityState extends State<DropdownEntity> {
  List<dynamic>? _data;
  String? _value;
  @override
  void initState() {
    _value = widget.initalValue;
    EntityService.getData(widget.entity).then((result) {
      if (result.success) {
        _data = result.data;
        if ((_data?.length ?? 0) == 1) {
          _value = _data?[0]['id'];
          widget.onChanged?.call(_value);
        }
        setState(() {});
      } else
        result.showMessage(context);
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return _data == null
        ? Text('${AppLocale.translate('Loading')}..')
        : DropdownButtonFormField<String>(
            decoration: InputDecoration(labelText: widget.label),
            value: _data?.any((d) =>
                        (!widget.isFilter ||
                            widget.filterValue == d[widget.filterField]) &&
                        d['id'] == _value) ??
                    false
                ? _value
                : null,
            onChanged: (v) {
              _value = v;
              if (widget.onChanged != null) widget.onChanged?.call(v);
              setState(() {});
            },
            items: (_data
                    ?.where((d) =>
                        !widget.isFilter ||
                        widget.filterValue == d[widget.filterField])
                    .map<DropdownMenuItem<String>>((item) => DropdownMenuItem(
                          child: Text(item['display'] ??
                              item['name'] ??
                              item['nameAr'] ??
                              item['nameEn'] ??
                              'N/A'),
                          value: item['id'],
                        ))
                    .toList() ??
                [])
              ..add(_value == null
                  ? DropdownMenuItem(
                      child: Container(),
                    )
                  : DropdownMenuItem(
                      child:
                          Text('غير محدد', style: TextStyle(color: Colors.red)),
                      value: null,
                    )),
          );
  }
}
